4.35. umbra.managers.patchesManager — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.35. umbra.managers.patchesManager

patchesManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `PatchesManager` and `Patches` classes.

Others:

## 4.35.1. Module Attributes

`umbra.managers.patchesManager.` `LOGGER`

## 4.35.2. Classes

class `umbra.managers.patchesManager.` `Patch`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for `PatchesManager` class patch.

  Parameters: | **kwargs – name, path, module, apply, uid. ( Key / Value pairs )

class `umbra.managers.patchesManager.` `PatchesManager`(historyFile=None, paths=None, extension='py')

  Bases: `object`

  This class defines the Application patches manager.

  Parameters: | historyFile – Patches history file. ( String ) paths – Patches paths. ( Tuple / List ) extension – Patches extension. ( String )

  `historyFile`

    This method is the property for self.__historyFile attribute.

    Returns: | self.__historyFile. ( String )

  `paths`

    This method is the property for self.__paths attribute.

    Returns: | self.__paths. ( Tuple / List )

  `extension`

    This method is the property for self.__extension attribute.

    Returns: | self.__extension. ( String )

  `patches`

    This method is the property for self.__patches attribute.

    Returns: | self.__patches. ( Dictionary )

  `listPatches`()

    This method returns the registered patches.

    Returns: | Patches list. ( List )

  `isPatchRegistered`(patch)

    This method returns if the given patch is registered.

    Parameters: | patch – Patch. ( String )
    Returns: | Is patch registered. ( Boolean )

  `registerPatch`(name, path)

    This method registers given patch.

    Parameters: | name – Patch name. ( String ) path – Patch path. ( String )
    Returns: | Method success. ( Boolean )

  `registerPatches`()

    This method registers the patches.

    Returns: | Method success. ( Boolean )

  `applyPatch`(patch)

    This method applies given patch.

    Parameters: | patch – Patch. ( Patch )
    Returns: | Method success. ( Boolean )

  `applyPatches`()

    This method applies the patches.

    Returns: | Method success. ( Boolean )

  `getPatchFromUid`(uid)

    This method returns the patch with given uid.

    Parameters: | uid – Patch uid. ( String )
    Returns: | Patch. ( Patch )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »